function plotConcentrationTime(trajectories, viablePoints, uFunc, timeSteps)
% Plot concentration-time graphs for each state.
%
%   plotConcentrationTime(trajectories, viablePoints, uFunc, timeSteps)
%
% Input parameters:
%
%   trajectories    n x m x p matrix, where n is the numer of time steps each
%                   trajectory is calculated for, m is the number of dimensions,
%                   and p is the number of points. The trajectories for p
%                   points over n time steps.
%
%   viablePoints    n x 1 matrix of boolean values, where n is the number of
%                   points from viablePoints. True for any point that
%                   has its trajectory entirely within the safe region defined
%                   by inSafeSetFunc.
%
%   uFunc           Scalar or Function of a scalar. The input, in 
%                   micrograms/minute, to the system.
%
%   timeSteps       1 x n matrix, where n is the number of timesteps. A vector
%                   with n values from 0 to tMax, where tMax is the time
%                   horizon.
%
% Output parameters:
%
%   none.


numInitialPoints = size(trajectories, 3);  
numDimensions = size(trajectories, 2);
lineWidth = 1;

subplot(ceil((numDimensions+1)/2), 2, 1)
if isa(uFunc, 'function_handle')
    plot(timeSteps, arrayfun(uFunc, timeSteps), 'black', 'LineWidth', lineWidth);
else
    plot(timeSteps, repmat(uFunc, size(timeSteps)), 'black', 'LineWidth', lineWidth);
end
xlabel('Time (minutes)')
ylabel('u (\mug/min)')

for d = 1:numDimensions,

if numDimensions == 4
subplot(ceil((numDimensions+1)/2), 2, d+2)
else
subplot(ceil((numDimensions+1)/2), 2, d+1)
end

hold on;
    for p = 1:numInitialPoints % for each initial point p
        if viablePoints(p)
            plot(timeSteps, trajectories(:,d,p), 'g', 'LineWidth', lineWidth);
        else % ~viablePoints(p)
            plot(timeSteps, trajectories(:,d,p), '--r', 'LineWidth', lineWidth);
        end % if
    end % for p
hold off;
xlabel('Time (minutes)')
switch d
    case 1 
        ylabel('cp (\mug/l)')
    case 2 
        ylabel('c1 (\mug/l)')
    case 3 
        ylabel('c2 (\mug/l)')
    case 4 
        ylabel('ce (\mug/l)')
    otherwise % nothing
end
end % for d




% axis equal
% zlabel('x3')
% camlight left; camlight right

end %function
